# -*- coding: utf-8 -*-
import atexit
import functools

try:
    from unittest2 import TestCase
    from unittest2 import skipIf
except ImportError:
    from unittest import TestCase
    from unittest import skipIf


def noop_decorator(func):
    @functools.wraps(func)
    def wrapped(*args, **kwargs):
        return func(*args, **kwargs)
    return wrapped


def atexit_register(func):
    """
    Uses either uwsgi's atexit mechanism, or atexit from the stdlib.

    When running under uwsgi, using their atexit handler is more reliable,
    especially when using gevent
    :param func: the function to call at exit
    """
    try:
        import uwsgi
        orig = getattr(uwsgi, 'atexit', None)
        if orig is not None:

            def uwsgi_atexit():
                if callable(orig):
                    orig()
                func()
            uwsgi_atexit.__name__ = func.__name__

        else:
            uwsgi_atexit = func

        uwsgi.atexit = uwsgi_atexit
    except ImportError:
        atexit.register(func)
